from distutils.core import setup
 
setup(name='prover9-mace4',
      version='0.5',
      description = 'Graphical User Interface (GUI) to prover9 and mace4',
      author = 'William McCune',
      author_email = 'mccune@cs.unm.edu',
      scripts = ['prover9-mace4.py'],
 )
